@@ -1,13 +1,14 @@
 package BackPAN::Index::Create;
-$BackPAN::Index::Create::VERSION = '0.08';
+$BackPAN::Index::Create::VERSION = '0.09';
 use 5.006;
 use strict;
 use warnings;
 use Exporter::Lite;
 use Path::Iterator::Rule;
-use Scalar::Util qw/ reftype /;
-use File::Spec::Functions qw/ catfile /;
-use Mojo::Loader;
+use Scalar::Util            qw/ reftype /;
+use File::Spec::Functions   qw/ catfile /;
+use Module::Find            qw/ findsubmod /;
+use Module::Runtime         qw/ require_module /;
 use Carp;
 use autodie;
 
@@ -31,10 +32,8 @@ sub create_backpan_index
     my $author_dir       = catfile($basedir, 'authors');
     my $stem             = catfile($author_dir, 'id');
     my $releases_only    = $argref->{releases_only} || 0;
-    my $loader           = Mojo::Loader->new()
-                           || croak "failed to create instance of Mojo::Loader";
-    my $plugins_ref      = $loader->search($PLUGIN_NAMESPACE);
-    my @plugin_basenames = map { my $p = $_; $p =~ s/^.*:://; $p } @$plugins_ref;
+    my @plugins          = findsubmod($PLUGIN_NAMESPACE);
+    my @plugin_basenames = map { my $p = $_; $p =~ s/^.*:://; $p } @plugins;
     my $fh;
 
 
@@ -49,9 +48,7 @@ sub create_backpan_index
     }
     my $plugin_class = $PLUGIN_NAMESPACE.'::'.$basename;
 
-    if (my $e = $loader->load($plugin_class)) {
-        croak "failed to load plugin for order '$order' ($plugin_class): $e";
-    }
+    require_module($plugin_class);
 
     if (exists($argref->{output})) {
         open($fh, '>', $argref->{output});
